unofficial mirror of guix-devel@gnu.org 
 help / color / mirror / code / Atom feed
* [PATCH] gnu: git: Add input for 'git-svn'.
@ 2016-09-27 19:45 Thomas Danckaert
  2016-09-28 13:24 ` 宋文武
  0 siblings, 1 reply; 2+ messages in thread
From: Thomas Danckaert @ 2016-09-27 19:45 UTC (permalink / raw)
  To: guix-devel

[-- Attachment #1: Type: Text/Plain, Size: 230 bytes --]

Hi Guix-devel,

this adds a perl dependency for git-svn.

git-svn uses Term::ReadKey to read a user's password during http 
authentication with an svn server (and perhaps for other 
authentication methods as well).

best,

Thomas

[-- Attachment #2: 0001-gnu-git-Add-input-for-git-svn.patch --]
[-- Type: Text/X-Patch, Size: 1814 bytes --]

From d5e3bf1a9e26a0fce4485f9af67118674fa6f547 Mon Sep 17 00:00:00 2001
From: Thomas Danckaert <thomas.danckaert@gmail.com>
Date: Tue, 27 Sep 2016 15:38:51 +0200
Subject: [PATCH] gnu: git: Add input for 'git-svn'.

---
 gnu/packages/version-control.scm | 8 +++++---
 1 file changed, 5 insertions(+), 3 deletions(-)

diff --git a/gnu/packages/version-control.scm b/gnu/packages/version-control.scm
index 29559bd..ef65a03 100644
--- a/gnu/packages/version-control.scm
+++ b/gnu/packages/version-control.scm
@@ -143,6 +143,7 @@ as well as the classic centralized workflow.")
 
       ;; For 'git-svn'.
       ("subversion" ,subversion)
+      ("perl-term-readkey" ,perl-term-readkey)
 
       ;; For 'git-send-email'
       ("perl-authen-sasl" ,perl-authen-sasl)
@@ -227,14 +228,15 @@ as well as the classic centralized workflow.")
                         (list gitk git-gui git-cit git-se git-svn)
                         (list gitk* git-gui* git-cit* git-se* git-svn*))
 
               ;; Tell 'git-svn' where Subversion is.
               (wrap-program git-svn*
                 `("PATH" ":" prefix
                   (,(string-append (assoc-ref inputs "subversion")
                                    "/bin")))
                 `("PERL5LIB" ":" prefix
-                  (,(string-append (assoc-ref inputs "subversion")
-                                   "/lib/perl5/site_perl")))
+                  ,(map (lambda (i) (string-append (assoc-ref inputs i)
+                                                   "/lib/perl5/site_perl"))
+                        '("subversion" "perl-term-readkey")))
 
                 ;; XXX: The .so for SVN/Core.pm lacks a RUNPATH, so
                 ;; help it find 'libsvn_client-1.so'.
@@ -227,14 +228,15 @@ as well as the classic centralized workflow.")
                         (list gitk* git-gui* git-cit* git-se* git-svn*))
 
-              ;; Tell 'git-svn' where Subversion is.
+              ;; Tell 'git-svn' where Subversion and perl-term-readkey are.
               (wrap-program git-svn*
                 `("PATH" ":" prefix
-- 
2.10.0


^ permalink raw reply related	[flat|nested] 2+ messages in thread

* Re: [PATCH] gnu: git: Add input for 'git-svn'.
  2016-09-27 19:45 [PATCH] gnu: git: Add input for 'git-svn' Thomas Danckaert
@ 2016-09-28 13:24 ` 宋文武
  0 siblings, 0 replies; 2+ messages in thread
From: 宋文武 @ 2016-09-28 13:24 UTC (permalink / raw)
  To: Thomas Danckaert; +Cc: guix-devel

Thomas Danckaert <thomas.danckaert@gmail.com> writes:

> Hi Guix-devel,
>
> this adds a perl dependency for git-svn.
>
> git-svn uses Term::ReadKey to read a user's password during http
> authentication with an svn server (and perhaps for other
> authentication methods as well).
>

Applied, thanks!

^ permalink raw reply	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2016-09-28 13:24 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2016-09-27 19:45 [PATCH] gnu: git: Add input for 'git-svn' Thomas Danckaert
2016-09-28 13:24 ` 宋文武

Code repositories for project(s) associated with this public inbox

	https://git.savannah.gnu.org/cgit/guix.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).